Hey Jani stop this, there was never a consensus on this kind of changes, and there never will be because to BC break is so huge it hurts.

Edin

Jani Taskinen wrote:
sniper          Sat Aug 13 20:46:53 2005 EDT

Modified files: /php-src/ext/wddx php_wddx.h wddx.c Log:
  - consistency fix, part 1/inf
http://cvs.php.net/diff.php/php-src/ext/wddx/php_wddx.h?r1=1.18&r2=1.19&ty=u
Index: php-src/ext/wddx/php_wddx.h
diff -u php-src/ext/wddx/php_wddx.h:1.18 php-src/ext/wddx/php_wddx.h:1.19
--- php-src/ext/wddx/php_wddx.h:1.18    Wed Aug  3 10:08:20 2005
+++ php-src/ext/wddx/php_wddx.h Sat Aug 13 20:46:51 2005
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
-/* $Id: php_wddx.h,v 1.18 2005/08/03 14:08:20 sniper Exp $ */
+/* $Id: php_wddx.h,v 1.19 2005/08/14 00:46:51 sniper Exp $ */
#ifndef PHP_WDDX_H
 #define PHP_WDDX_H
@@ -31,7 +31,7 @@
 PHP_FUNCTION(wddx_packet_start);
 PHP_FUNCTION(wddx_packet_end);
 PHP_FUNCTION(wddx_add_vars);
-PHP_FUNCTION(wddx_deserialize);
+PHP_FUNCTION(wddx_unserialize);
#else http://cvs.php.net/diff.php/php-src/ext/wddx/wddx.c?r1=1.120&r2=1.121&ty=u
Index: php-src/ext/wddx/wddx.c
diff -u php-src/ext/wddx/wddx.c:1.120 php-src/ext/wddx/wddx.c:1.121
--- php-src/ext/wddx/wddx.c:1.120       Wed Aug 10 18:36:20 2005
+++ php-src/ext/wddx/wddx.c     Sat Aug 13 20:46:51 2005
@@ -16,7 +16,7 @@
    +----------------------------------------------------------------------+
  */
-/* $Id: wddx.c,v 1.120 2005/08/10 22:36:20 iliaa Exp $ */
+/* $Id: wddx.c,v 1.121 2005/08/14 00:46:51 sniper Exp $ */
#include "php.h" @@ -57,8 +57,8 @@
 #define EL_FIELD                               "field"
 #define EL_DATETIME                            "dateTime"
-#define php_wddx_deserialize(a,b) \
-       php_wddx_deserialize_ex((a)->value.str.val, (a)->value.str.len, (b))
+#define php_wddx_unserialize(a,b) \
+       php_wddx_unserialize_ex((a)->value.str.val, (a)->value.str.len, (b))
#define SET_STACK_VARNAME \
                if (stack->varname) {                                           
     \
@@ -105,7 +105,8 @@
        PHP_FE(wddx_packet_start, NULL)
        PHP_FE(wddx_packet_end, NULL)
        PHP_FE(wddx_add_vars, NULL)
-       PHP_FE(wddx_deserialize, NULL)
+       PHP_FE(wddx_unserialize, NULL)
+       PHP_FALIAS(wddx_unserialize, wddx_deserialize, NULL)
        {NULL, NULL, NULL}
 };
 /* }}} */
@@ -270,7 +271,7 @@
        
        MAKE_STD_ZVAL(retval);
- if ((ret = php_wddx_deserialize_ex((char *)val, vallen, retval)) == SUCCESS) {
+       if ((ret = php_wddx_unserialize_ex((char *)val, vallen, retval)) == 
SUCCESS) {
for (zend_hash_internal_pointer_reset(Z_ARRVAL_P(retval));
                         zend_hash_get_current_data(Z_ARRVAL_P(retval), (void **) 
&ent) == SUCCESS;
@@ -1121,9 +1122,9 @@
 }
 /* }}} */
-/* {{{ php_wddx_deserialize_ex
+/* {{{ php_wddx_unserialize_ex
  */
-int php_wddx_deserialize_ex(char *value, int vallen, zval *return_value)
+int php_wddx_unserialize_ex(char *value, int vallen, zval *return_value)
 {
        wddx_stack stack;
        XML_Parser parser;
@@ -1329,9 +1330,9 @@
 }
 /* }}} */
-/* {{{ proto mixed wddx_deserialize(mixed packet) - Deserializes given packet and returns a PHP value */
-PHP_FUNCTION(wddx_deserialize)
+/* {{{ proto mixed wddx_unserialize(mixed packet) + Unserializes given packet and returns a PHP value */
+PHP_FUNCTION(wddx_unserialize)
 {
        zval *packet;
        char *payload;
@@ -1358,7 +1359,7 @@
        if (payload_len == 0)
                return;
- php_wddx_deserialize_ex(payload, payload_len, return_value);
+       php_wddx_unserialize_ex(payload, payload_len, return_value);
                
        if (stream)
                pefree(payload, 0);


--
PHP Internals - PHP Runtime Development Mailing List
To unsubscribe, visit: http://www.php.net/unsub.php

Reply via email to